Module: Rubbr::Builder
- Defined in:
- lib/rubbr/builder.rb,
lib/rubbr/builder/ps.rb,
lib/rubbr/builder/dvi.rb,
lib/rubbr/builder/tex.rb
Overview
Handles the business of building latex (and bibtex if needed) source files into binary formats as dvi, ps, and pdf. The latex and bibtex utilites need to be run a certain number of times so that things like table of contents, references, citations, etc become proper. This module tries to solve this issue by running the needed utilities only as many times as needed.
Defined Under Namespace
Class Method Summary collapse
-
.build ⇒ Object
Build to the spesified format.
Class Method Details
.build ⇒ Object
Build to the spesified format.
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/rubbr/builder.rb', line 14 def self.build return unless Rubbr::Change.d? if Rubbr.[:engine] == :pdflatex Rubbr::Builder::Tex.build else case Rubbr.[:format] when :dvi Rubbr::Builder::Tex.build when :ps Rubbr::Builder::Tex.build Rubbr::Builder::Dvi.build else Rubbr::Builder::Tex.build Rubbr::Builder::Dvi.build Rubbr::Builder::Ps.build end end end |